.. _mock_functions:

Detailed API for Clustering Statistics on Mock Catalogs
=========================================================

All of these can be imported from :py:mod:`Corrfunc.mocks`. See the complete reference here :py:mod:`Corrfunc`.`

.. currentmodule:: Corrfunc.mocks

Clustering in 2-D
-------------------

* Pair counts (auto or cross) correlations for :math:`\xi(rp, \pi)` -- :py:mod:`Corrfunc.mocks.DDrppi_mocks`
* Pair counts (auto or cross) correlations for :math:`\xi(s, \mu)` -- :py:mod:`Corrfunc.mocks.DDsmu_mocks`     

Angular clustering
--------------------

* Pair counts (auto or cross) correlations for :math:`\omega(\theta)` -- :py:mod:`Corrfunc.mocks.DDtheta_mocks`

                     
Counts-in-cells
----------------

* Void Probability functions and counts-in-cells stats :math:`pN(r)` -- :py:mod:`Corrfunc.mocks.vpf_mocks`

